#include "aboutdlg.h"
#include "ui_aboutdlg.h"
#include "creditsdlg.h"

AboutDlg::AboutDlg(QWidget *parent) :
    QDialog(parent),
    m_ui(new Ui::AboutDlg)
{
    m_ui->setupUi(this);
}

AboutDlg::~AboutDlg()
{
    delete m_ui;
}

void AboutDlg::on_creditsButton_clicked()
{
    CreditsDlg *credits = new CreditsDlg(this);
    credits->exec();
}

void AboutDlg::on_licenseButton_clicked()
{
    LicenseDlg *license = new LicenseDlg(this);
    license->exec();
}

void AboutDlg::on_webButton_clicked()
{
    QUrl webUrl("http://irreco.garage.maemo.org");
    QDesktopServices::openUrl(webUrl);
}
